# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SharedItemInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shared_topics': 'int',
        'shared_users': 'int',
        'shared_workbooks': 'int'
    }

    attribute_map = {
        'shared_topics': 'sharedTopics',
        'shared_users': 'sharedUsers',
        'shared_workbooks': 'sharedWorkbooks'
    }

    def __init__(self, shared_topics=None, shared_users=None, shared_workbooks=None):
        """
        SharedItemInformation - a model defined in Swagger
        """

        self._shared_topics = None
        self._shared_users = None
        self._shared_workbooks = None

        if shared_topics is not None:
          self.shared_topics = shared_topics
        if shared_users is not None:
          self.shared_users = shared_users
        if shared_workbooks is not None:
          self.shared_workbooks = shared_workbooks

    @property
    def shared_topics(self):
        """
        Gets the shared_topics of this SharedItemInformation.
        The number of topics shared

        :return: The shared_topics of this SharedItemInformation.
        :rtype: int
        """
        return self._shared_topics

    @shared_topics.setter
    def shared_topics(self, shared_topics):
        """
        Sets the shared_topics of this SharedItemInformation.
        The number of topics shared

        :param shared_topics: The shared_topics of this SharedItemInformation.
        :type: int
        """

        self._shared_topics = shared_topics

    @property
    def shared_users(self):
        """
        Gets the shared_users of this SharedItemInformation.
        The number of users shared

        :return: The shared_users of this SharedItemInformation.
        :rtype: int
        """
        return self._shared_users

    @shared_users.setter
    def shared_users(self, shared_users):
        """
        Sets the shared_users of this SharedItemInformation.
        The number of users shared

        :param shared_users: The shared_users of this SharedItemInformation.
        :type: int
        """

        self._shared_users = shared_users

    @property
    def shared_workbooks(self):
        """
        Gets the shared_workbooks of this SharedItemInformation.
        The number of workbooks shared

        :return: The shared_workbooks of this SharedItemInformation.
        :rtype: int
        """
        return self._shared_workbooks

    @shared_workbooks.setter
    def shared_workbooks(self, shared_workbooks):
        """
        Sets the shared_workbooks of this SharedItemInformation.
        The number of workbooks shared

        :param shared_workbooks: The shared_workbooks of this SharedItemInformation.
        :type: int
        """

        self._shared_workbooks = shared_workbooks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SharedItemInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemFinderInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cron_schedule': 'list[str]',
        'description': 'str',
        'enabled': 'bool',
        'fixed_list_searches': 'list[FixedListSearchV1]',
        'hierarchy_searches': 'list[HierarchySearchV1]',
        'include_hierarchy': 'bool',
        'name': 'str',
        'property_searches': 'list[PropertySearchV1]',
        'scaling_table_uuid_column_searches': 'list[ScalingTableUUIDColumnSearchV1]',
        'scoped_to': 'str',
        'searches': 'list[SwapAcrossAssetsSearchV1]',
        'skip_job_scheduling': 'bool',
        'stored_table_searches': 'list[StoredTableSearchV1]',
        'timezone': 'str'
    }

    attribute_map = {
        'cron_schedule': 'cronSchedule',
        'description': 'description',
        'enabled': 'enabled',
        'fixed_list_searches': 'fixedListSearches',
        'hierarchy_searches': 'hierarchySearches',
        'include_hierarchy': 'includeHierarchy',
        'name': 'name',
        'property_searches': 'propertySearches',
        'scaling_table_uuid_column_searches': 'scalingTableUUIDColumnSearches',
        'scoped_to': 'scopedTo',
        'searches': 'searches',
        'skip_job_scheduling': 'skipJobScheduling',
        'stored_table_searches': 'storedTableSearches',
        'timezone': 'timezone'
    }

    def __init__(self, cron_schedule=None, description=None, enabled=True, fixed_list_searches=None, hierarchy_searches=None, include_hierarchy=False, name=None, property_searches=None, scaling_table_uuid_column_searches=None, scoped_to=None, searches=None, skip_job_scheduling=False, stored_table_searches=None, timezone=None):
        """
        ItemFinderInputV1 - a model defined in Swagger
        """

        self._cron_schedule = None
        self._description = None
        self._enabled = None
        self._fixed_list_searches = None
        self._hierarchy_searches = None
        self._include_hierarchy = None
        self._name = None
        self._property_searches = None
        self._scaling_table_uuid_column_searches = None
        self._scoped_to = None
        self._searches = None
        self._skip_job_scheduling = None
        self._stored_table_searches = None
        self._timezone = None

        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if description is not None:
          self.description = description
        if enabled is not None:
          self.enabled = enabled
        if fixed_list_searches is not None:
          self.fixed_list_searches = fixed_list_searches
        if hierarchy_searches is not None:
          self.hierarchy_searches = hierarchy_searches
        if include_hierarchy is not None:
          self.include_hierarchy = include_hierarchy
        if name is not None:
          self.name = name
        if property_searches is not None:
          self.property_searches = property_searches
        if scaling_table_uuid_column_searches is not None:
          self.scaling_table_uuid_column_searches = scaling_table_uuid_column_searches
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if searches is not None:
          self.searches = searches
        if skip_job_scheduling is not None:
          self.skip_job_scheduling = skip_job_scheduling
        if stored_table_searches is not None:
          self.stored_table_searches = stored_table_searches
        if timezone is not None:
          self.timezone = timezone

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this ItemFinderInputV1.
        The item finder's check interval(s) as a list of cron expressions. If the list is empty, the system wide default check schedule is used. For more information about cron expressions, see  http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html

        :return: The cron_schedule of this ItemFinderInputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this ItemFinderInputV1.
        The item finder's check interval(s) as a list of cron expressions. If the list is empty, the system wide default check schedule is used. For more information about cron expressions, see  http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html

        :param cron_schedule: The cron_schedule of this ItemFinderInputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def description(self):
        """
        Gets the description of this ItemFinderInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this ItemFinderInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ItemFinderInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this ItemFinderInputV1.
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this ItemFinderInputV1.
        Whether the item finder is enabled

        :return: The enabled of this ItemFinderInputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ItemFinderInputV1.
        Whether the item finder is enabled

        :param enabled: The enabled of this ItemFinderInputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def fixed_list_searches(self):
        """
        Gets the fixed_list_searches of this ItemFinderInputV1.
        The list of searches containing a list of item IDs to always include or exclude in the output

        :return: The fixed_list_searches of this ItemFinderInputV1.
        :rtype: list[FixedListSearchV1]
        """
        return self._fixed_list_searches

    @fixed_list_searches.setter
    def fixed_list_searches(self, fixed_list_searches):
        """
        Sets the fixed_list_searches of this ItemFinderInputV1.
        The list of searches containing a list of item IDs to always include or exclude in the output

        :param fixed_list_searches: The fixed_list_searches of this ItemFinderInputV1.
        :type: list[FixedListSearchV1]
        """

        self._fixed_list_searches = fixed_list_searches

    @property
    def hierarchy_searches(self):
        """
        Gets the hierarchy_searches of this ItemFinderInputV1.
        The list of searches for finding hierarchy nodes based on item hierarchies. This search can only be used if includeHierarchy is true.

        :return: The hierarchy_searches of this ItemFinderInputV1.
        :rtype: list[HierarchySearchV1]
        """
        return self._hierarchy_searches

    @hierarchy_searches.setter
    def hierarchy_searches(self, hierarchy_searches):
        """
        Sets the hierarchy_searches of this ItemFinderInputV1.
        The list of searches for finding hierarchy nodes based on item hierarchies. This search can only be used if includeHierarchy is true.

        :param hierarchy_searches: The hierarchy_searches of this ItemFinderInputV1.
        :type: list[HierarchySearchV1]
        """

        self._hierarchy_searches = hierarchy_searches

    @property
    def include_hierarchy(self):
        """
        Gets the include_hierarchy of this ItemFinderInputV1.
        Whether the item finder will include hierarchy information

        :return: The include_hierarchy of this ItemFinderInputV1.
        :rtype: bool
        """
        return self._include_hierarchy

    @include_hierarchy.setter
    def include_hierarchy(self, include_hierarchy):
        """
        Sets the include_hierarchy of this ItemFinderInputV1.
        Whether the item finder will include hierarchy information

        :param include_hierarchy: The include_hierarchy of this ItemFinderInputV1.
        :type: bool
        """

        self._include_hierarchy = include_hierarchy

    @property
    def name(self):
        """
        Gets the name of this ItemFinderInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this ItemFinderInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ItemFinderInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this ItemFinderInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def property_searches(self):
        """
        Gets the property_searches of this ItemFinderInputV1.
        The list of searches based on properties

        :return: The property_searches of this ItemFinderInputV1.
        :rtype: list[PropertySearchV1]
        """
        return self._property_searches

    @property_searches.setter
    def property_searches(self, property_searches):
        """
        Sets the property_searches of this ItemFinderInputV1.
        The list of searches based on properties

        :param property_searches: The property_searches of this ItemFinderInputV1.
        :type: list[PropertySearchV1]
        """

        self._property_searches = property_searches

    @property
    def scaling_table_uuid_column_searches(self):
        """
        Gets the scaling_table_uuid_column_searches of this ItemFinderInputV1.
        The list of searches for finding items based on a materialized table's UUID column

        :return: The scaling_table_uuid_column_searches of this ItemFinderInputV1.
        :rtype: list[ScalingTableUUIDColumnSearchV1]
        """
        return self._scaling_table_uuid_column_searches

    @scaling_table_uuid_column_searches.setter
    def scaling_table_uuid_column_searches(self, scaling_table_uuid_column_searches):
        """
        Sets the scaling_table_uuid_column_searches of this ItemFinderInputV1.
        The list of searches for finding items based on a materialized table's UUID column

        :param scaling_table_uuid_column_searches: The scaling_table_uuid_column_searches of this ItemFinderInputV1.
        :type: list[ScalingTableUUIDColumnSearchV1]
        """

        self._scaling_table_uuid_column_searches = scaling_table_uuid_column_searches

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ItemFinderInputV1.
        The ID of the workbook to which the item finder will be scoped. If not provided, it will have a global scope

        :return: The scoped_to of this ItemFinderInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ItemFinderInputV1.
        The ID of the workbook to which the item finder will be scoped. If not provided, it will have a global scope

        :param scoped_to: The scoped_to of this ItemFinderInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def searches(self):
        """
        Gets the searches of this ItemFinderInputV1.
        The list of searches for swapping across assets to find items

        :return: The searches of this ItemFinderInputV1.
        :rtype: list[SwapAcrossAssetsSearchV1]
        """
        return self._searches

    @searches.setter
    def searches(self, searches):
        """
        Sets the searches of this ItemFinderInputV1.
        The list of searches for swapping across assets to find items

        :param searches: The searches of this ItemFinderInputV1.
        :type: list[SwapAcrossAssetsSearchV1]
        """

        self._searches = searches

    @property
    def skip_job_scheduling(self):
        """
        Gets the skip_job_scheduling of this ItemFinderInputV1.
        If true, the Item Finder job will not be scheduled. Typically used when executing searches immediately upon creation. Cannot be true if a cron schedule is provided, as those options are mutually exclusive. Set this to true any time the job should not be scheduled when updating or creating an Item Finder

        :return: The skip_job_scheduling of this ItemFinderInputV1.
        :rtype: bool
        """
        return self._skip_job_scheduling

    @skip_job_scheduling.setter
    def skip_job_scheduling(self, skip_job_scheduling):
        """
        Sets the skip_job_scheduling of this ItemFinderInputV1.
        If true, the Item Finder job will not be scheduled. Typically used when executing searches immediately upon creation. Cannot be true if a cron schedule is provided, as those options are mutually exclusive. Set this to true any time the job should not be scheduled when updating or creating an Item Finder

        :param skip_job_scheduling: The skip_job_scheduling of this ItemFinderInputV1.
        :type: bool
        """

        self._skip_job_scheduling = skip_job_scheduling

    @property
    def stored_table_searches(self):
        """
        Gets the stored_table_searches of this ItemFinderInputV1.
        The list of searches based on stored table values and properties

        :return: The stored_table_searches of this ItemFinderInputV1.
        :rtype: list[StoredTableSearchV1]
        """
        return self._stored_table_searches

    @stored_table_searches.setter
    def stored_table_searches(self, stored_table_searches):
        """
        Sets the stored_table_searches of this ItemFinderInputV1.
        The list of searches based on stored table values and properties

        :param stored_table_searches: The stored_table_searches of this ItemFinderInputV1.
        :type: list[StoredTableSearchV1]
        """

        self._stored_table_searches = stored_table_searches

    @property
    def timezone(self):
        """
        Gets the timezone of this ItemFinderInputV1.
        The IANA timezone in which the scheduled times will be run, defaults to UTC

        :return: The timezone of this ItemFinderInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ItemFinderInputV1.
        The IANA timezone in which the scheduled times will be run, defaults to UTC

        :param timezone: The timezone of this ItemFinderInputV1.
        :type: str
        """

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemFinderInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DatasourceAccessStatsV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'datasource_class': 'str',
        'datasource_id': 'str',
        'distinct_items_accessed_past_day': 'int',
        'item_type': 'str'
    }

    attribute_map = {
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'distinct_items_accessed_past_day': 'distinctItemsAccessedPastDay',
        'item_type': 'itemType'
    }

    def __init__(self, datasource_class=None, datasource_id=None, distinct_items_accessed_past_day=None, item_type=None):
        """
        DatasourceAccessStatsV1 - a model defined in Swagger
        """

        self._datasource_class = None
        self._datasource_id = None
        self._distinct_items_accessed_past_day = None
        self._item_type = None

        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if distinct_items_accessed_past_day is not None:
          self.distinct_items_accessed_past_day = distinct_items_accessed_past_day
        if item_type is not None:
          self.item_type = item_type

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this DatasourceAccessStatsV1.
        The datasource class.

        :return: The datasource_class of this DatasourceAccessStatsV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this DatasourceAccessStatsV1.
        The datasource class.

        :param datasource_class: The datasource_class of this DatasourceAccessStatsV1.
        :type: str
        """
        if datasource_class is None:
            raise ValueError("Invalid value for `datasource_class`, must not be `None`")

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this DatasourceAccessStatsV1.
        The datasource ID.

        :return: The datasource_id of this DatasourceAccessStatsV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this DatasourceAccessStatsV1.
        The datasource ID.

        :param datasource_id: The datasource_id of this DatasourceAccessStatsV1.
        :type: str
        """
        if datasource_id is None:
            raise ValueError("Invalid value for `datasource_id`, must not be `None`")

        self._datasource_id = datasource_id

    @property
    def distinct_items_accessed_past_day(self):
        """
        Gets the distinct_items_accessed_past_day of this DatasourceAccessStatsV1.
        The number of distinct items from the specified datasource of the specified type accessed in the past UTC day.

        :return: The distinct_items_accessed_past_day of this DatasourceAccessStatsV1.
        :rtype: int
        """
        return self._distinct_items_accessed_past_day

    @distinct_items_accessed_past_day.setter
    def distinct_items_accessed_past_day(self, distinct_items_accessed_past_day):
        """
        Sets the distinct_items_accessed_past_day of this DatasourceAccessStatsV1.
        The number of distinct items from the specified datasource of the specified type accessed in the past UTC day.

        :param distinct_items_accessed_past_day: The distinct_items_accessed_past_day of this DatasourceAccessStatsV1.
        :type: int
        """
        if distinct_items_accessed_past_day is None:
            raise ValueError("Invalid value for `distinct_items_accessed_past_day`, must not be `None`")

        self._distinct_items_accessed_past_day = distinct_items_accessed_past_day

    @property
    def item_type(self):
        """
        Gets the item_type of this DatasourceAccessStatsV1.
        The type of items accessed.

        :return: The item_type of this DatasourceAccessStatsV1.
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """
        Sets the item_type of this DatasourceAccessStatsV1.
        The type of items accessed.

        :param item_type: The item_type of this DatasourceAccessStatsV1.
        :type: str
        """
        if item_type is None:
            raise ValueError("Invalid value for `item_type`, must not be `None`")

        self._item_type = item_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DatasourceAccessStatsV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class JoinInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'left_column_definition_id': 'str',
        'right': 'str',
        'right_column_definition_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        'left_column_definition_id': 'leftColumnDefinitionId',
        'right': 'right',
        'right_column_definition_id': 'rightColumnDefinitionId',
        'type': 'type'
    }

    def __init__(self, left_column_definition_id=None, right=None, right_column_definition_id=None, type=None):
        """
        JoinInputV1 - a model defined in Swagger
        """

        self._left_column_definition_id = None
        self._right = None
        self._right_column_definition_id = None
        self._type = None

        if left_column_definition_id is not None:
          self.left_column_definition_id = left_column_definition_id
        if right is not None:
          self.right = right
        if right_column_definition_id is not None:
          self.right_column_definition_id = right_column_definition_id
        if type is not None:
          self.type = type

    @property
    def left_column_definition_id(self):
        """
        Gets the left_column_definition_id of this JoinInputV1.
        Column definition ID from the left table

        :return: The left_column_definition_id of this JoinInputV1.
        :rtype: str
        """
        return self._left_column_definition_id

    @left_column_definition_id.setter
    def left_column_definition_id(self, left_column_definition_id):
        """
        Sets the left_column_definition_id of this JoinInputV1.
        Column definition ID from the left table

        :param left_column_definition_id: The left_column_definition_id of this JoinInputV1.
        :type: str
        """
        if left_column_definition_id is None:
            raise ValueError("Invalid value for `left_column_definition_id`, must not be `None`")

        self._left_column_definition_id = left_column_definition_id

    @property
    def right(self):
        """
        Gets the right of this JoinInputV1.
        Right side table source for the join

        :return: The right of this JoinInputV1.
        :rtype: str
        """
        return self._right

    @right.setter
    def right(self, right):
        """
        Sets the right of this JoinInputV1.
        Right side table source for the join

        :param right: The right of this JoinInputV1.
        :type: str
        """
        if right is None:
            raise ValueError("Invalid value for `right`, must not be `None`")

        self._right = right

    @property
    def right_column_definition_id(self):
        """
        Gets the right_column_definition_id of this JoinInputV1.
        Column definition ID from the right table

        :return: The right_column_definition_id of this JoinInputV1.
        :rtype: str
        """
        return self._right_column_definition_id

    @right_column_definition_id.setter
    def right_column_definition_id(self, right_column_definition_id):
        """
        Sets the right_column_definition_id of this JoinInputV1.
        Column definition ID from the right table

        :param right_column_definition_id: The right_column_definition_id of this JoinInputV1.
        :type: str
        """
        if right_column_definition_id is None:
            raise ValueError("Invalid value for `right_column_definition_id`, must not be `None`")

        self._right_column_definition_id = right_column_definition_id

    @property
    def type(self):
        """
        Gets the type of this JoinInputV1.
        Type of join

        :return: The type of this JoinInputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this JoinInputV1.
        Type of join

        :param type: The type of this JoinInputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, JoinInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.103.1-v202602120843-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelFormulaCreatorRuleV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'ModelRuleInputV1String',
        'formula': 'ModelRuleInputV1String',
        'identity_id': 'ModelRuleInputV1UUID',
        'name': 'ModelRuleInputV1String',
        'parameters': 'ModelRuleInputV1ListString',
        'permission_string': 'ModelRuleInputV1String',
        'scoped_to': 'ModelRuleInputV1UUID',
        'variable_parameter_strings': 'ModelRuleInputV1ListString',
        'variable_parameters': 'ModelRuleInputV1ListString'
    }

    attribute_map = {
        'description': 'description',
        'formula': 'formula',
        'identity_id': 'identityId',
        'name': 'name',
        'parameters': 'parameters',
        'permission_string': 'permissionString',
        'scoped_to': 'scopedTo',
        'variable_parameter_strings': 'variableParameterStrings',
        'variable_parameters': 'variableParameters'
    }

    def __init__(self, description=None, formula=None, identity_id=None, name=None, parameters=None, permission_string=None, scoped_to=None, variable_parameter_strings=None, variable_parameters=None):
        """
        ModelFormulaCreatorRuleV1 - a model defined in Swagger
        """

        self._description = None
        self._formula = None
        self._identity_id = None
        self._name = None
        self._parameters = None
        self._permission_string = None
        self._scoped_to = None
        self._variable_parameter_strings = None
        self._variable_parameters = None

        if description is not None:
          self.description = description
        if formula is not None:
          self.formula = formula
        if identity_id is not None:
          self.identity_id = identity_id
        if name is not None:
          self.name = name
        if parameters is not None:
          self.parameters = parameters
        if permission_string is not None:
          self.permission_string = permission_string
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if variable_parameter_strings is not None:
          self.variable_parameter_strings = variable_parameter_strings
        if variable_parameters is not None:
          self.variable_parameters = variable_parameters

    @property
    def description(self):
        """
        Gets the description of this ModelFormulaCreatorRuleV1.

        :return: The description of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ModelFormulaCreatorRuleV1.

        :param description: The description of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """

        self._description = description

    @property
    def formula(self):
        """
        Gets the formula of this ModelFormulaCreatorRuleV1.

        :return: The formula of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this ModelFormulaCreatorRuleV1.

        :param formula: The formula of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """
        if formula is None:
            raise ValueError("Invalid value for `formula`, must not be `None`")

        self._formula = formula

    @property
    def identity_id(self):
        """
        Gets the identity_id of this ModelFormulaCreatorRuleV1.

        :return: The identity_id of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1UUID
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this ModelFormulaCreatorRuleV1.

        :param identity_id: The identity_id of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1UUID
        """

        self._identity_id = identity_id

    @property
    def name(self):
        """
        Gets the name of this ModelFormulaCreatorRuleV1.

        :return: The name of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ModelFormulaCreatorRuleV1.

        :param name: The name of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def parameters(self):
        """
        Gets the parameters of this ModelFormulaCreatorRuleV1.

        :return: The parameters of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1ListString
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this ModelFormulaCreatorRuleV1.

        :param parameters: The parameters of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1ListString
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")

        self._parameters = parameters

    @property
    def permission_string(self):
        """
        Gets the permission_string of this ModelFormulaCreatorRuleV1.

        :return: The permission_string of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1String
        """
        return self._permission_string

    @permission_string.setter
    def permission_string(self, permission_string):
        """
        Sets the permission_string of this ModelFormulaCreatorRuleV1.

        :param permission_string: The permission_string of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1String
        """

        self._permission_string = permission_string

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ModelFormulaCreatorRuleV1.

        :return: The scoped_to of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1UUID
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ModelFormulaCreatorRuleV1.

        :param scoped_to: The scoped_to of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1UUID
        """

        self._scoped_to = scoped_to

    @property
    def variable_parameter_strings(self):
        """
        Gets the variable_parameter_strings of this ModelFormulaCreatorRuleV1.

        :return: The variable_parameter_strings of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1ListString
        """
        return self._variable_parameter_strings

    @variable_parameter_strings.setter
    def variable_parameter_strings(self, variable_parameter_strings):
        """
        Sets the variable_parameter_strings of this ModelFormulaCreatorRuleV1.

        :param variable_parameter_strings: The variable_parameter_strings of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1ListString
        """

        self._variable_parameter_strings = variable_parameter_strings

    @property
    def variable_parameters(self):
        """
        Gets the variable_parameters of this ModelFormulaCreatorRuleV1.

        :return: The variable_parameters of this ModelFormulaCreatorRuleV1.
        :rtype: ModelRuleInputV1ListString
        """
        return self._variable_parameters

    @variable_parameters.setter
    def variable_parameters(self, variable_parameters):
        """
        Sets the variable_parameters of this ModelFormulaCreatorRuleV1.

        :param variable_parameters: The variable_parameters of this ModelFormulaCreatorRuleV1.
        :type: ModelRuleInputV1ListString
        """

        self._variable_parameters = variable_parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelFormulaCreatorRuleV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
